@@ -6,6 +6,7 @@ from typing import List, Optional, Sequence
 import uuid
 
 import mincepy
+from . import pyshim
 from . import utils
 
 __all__ = 'Command', 'command', 'PythonCommand'
@@ -31,10 +32,30 @@ class Command(mincepy.SimpleSavable, metaclass=ABCMeta):
         """Copy any command files to the given path"""
 
 
-def command(cmd, args: Sequence = (), type: str = 'python-function') -> Command:  # pylint: disable=redefined-builtin
-    """Create a new command"""
+def command(cmd, args: Sequence = (), type: str = 'python-function', **kwargs) -> Command:  # pylint: disable=redefined-builtin
+    """Command creation factory.
+
+    :param cmd: the command specification, for python function this should be a function or class
+        method
+    :param args: the (positional) argument for the command
+    :param type: the command type, default is 'python-function'
+    :param kwargs: additional arguments that will be passed as kwargs to the relevant command class
+        constructor so have a look at it's constructor for more details
+    """
     if type == 'python-function':
-        function = 'run'
+        return PythonCommand.build(cmd, args, **kwargs)
+
+    raise ValueError("Unknown command type '{}'".format(type))
+
+
+class PythonCommand(Command):
+    TYPE_ID = uuid.UUID('61736206-729b-4a0b-9fac-6b5e71123ba0')
+    ATTRS = ('_script_file', '_function', '_kwargs')
+
+    @classmethod
+    def build(cls, cmd, args: Sequence = (), dynamic=False, **kwargs):
+        function = 'run'  # The default function name
+
         if inspect.ismethod(cmd):
             script_file = sys.modules[cmd.__module__].__file__
             function = utils.get_symbol_name(cmd)
@@ -52,17 +73,35 @@ def command(cmd, args: Sequence = (), type: str = 'python-function') -> Command:
         else:
             raise ValueError("Unknown python function command '{}".format(cmd))
 
-        return PythonCommand(script_file, function, args)
+        return PythonCommand(script_file, function, args, dynamic=dynamic, **kwargs)
 
-    raise ValueError("Unknown command type '{}'".format(type))
+    # pylint: disable=too-many-arguments
+    def __init__(self,
+                 script_file,
+                 function='run',
+                 args=(),
+                 kwargs: dict = None,
+                 dynamic=False,
+                 historian=None):
+        """
+        Create a python command
 
+        :param script_file: the path to the script file
+        :param function: the name of the function in the script file to invoke
+        :param args: the arguments to the function
+        :param kwargs: the keyword arguments to the function
+        :param dynamic: whether to run the function dynamically
+            (i.e. import it when the command is ran)
+        :param historian: the historian
+        """
+        if dynamic:
+            # Create the arguments for run_dynamically
+            kwargs = dict(script_file=script_file, function=function, args=args, kwargs=kwargs)
+            args = ()  # Just rely on the kwargs
+            script_file = pyshim.__file__
+            function = pyshim.run_dynamically.__name__
 
-class PythonCommand(Command):
-    TYPE_ID = uuid.UUID('61736206-729b-4a0b-9fac-6b5e71123ba0')
-    ATTRS = ('_script_file', '_function')
-
-    def __init__(self, script_file, function='run', args=(), historian=None):
-        super(PythonCommand, self).__init__(args)
+        super().__init__(args)
         self._historian = historian or mincepy.get_historian()
 
         script_file = Path(script_file)
@@ -70,6 +109,7 @@ class PythonCommand(Command):
         self._script_file.from_disk(script_file)
 
         self._function = function
+        self._kwargs = kwargs or {}
 
     def __str__(self):
         return "{}@{}{}".format(self._script_file.filename, self._function, self._args)
@@ -89,7 +129,7 @@ class PythonCommand(Command):
         with self._script_file.open() as file:
             script = utils.load_script(file)
             run = utils.get_symbol(script, self._function)
-            return run(*self._args)
+            return run(*self._args, **self._kwargs)
 
     def copy_files_to(self, path):
         self._script_file.to_disk(path)
